local assets=
{
	Asset("ANIM", "anim/rubyspear.zip"),
	Asset("ANIM", "anim/ruby_spear.zip"),
    Asset("ATLAS", "images/inventoryimages/rubyspear.xml"),
}

local function applyupgrades(inst)

	local max_upgrades = 40
	local upgrades = math.min(inst.level, max_upgrades)
	inst:AddComponent("weapon")
	inst.components.weapon:SetDamage(math.ceil(TUNING.RUBYSPEAR_DAMAGE - upgrades))
    inst.components.weapon:SetOnAttack(
	function(inst, owner, target)
		if inst.level < 40 then
			inst:AddComponent("lootdropper")
			if math.random() < .2 then
				inst.SoundEmitter:PlaySound("dontstarve/wilson/fireball_explo")
				inst.components.lootdropper:SpawnLootPrefab("ash")
				inst.components.lootdropper:SpawnLootPrefab("ash")
				inst.level = math.min(inst.level + 7, max_upgrades)
			end
		end
		inst.level = math.min(inst.level + 1, max_upgrades)
		applyupgrades(inst)
	end)
end

local function onrepaired(inst, owner, repair_item)	
	inst.SoundEmitter:PlaySound("dontstarve/common/fireAddFuel")
	inst.SoundEmitter:PlaySound("dontstarve/wilson/equip_item_gold")
	inst.SoundEmitter:PlaySound("dontstarve/wilson/equip_item_gold")
	if repair_item.prefab == "ash" then
		-- if math.random() < 1/2 then
			-- if inst.level < 40 then
				-- inst.components.talker:Say("It's sharper!")
				-- inst.SoundEmitter:PlaySound("dontstarve_DLC001/common/iceboulder_smash")
			-- elseif inst.level >= 40 then
				-- inst.components.talker:Say("It reached its limit.")
			-- end
			inst.level = math.max(inst.level - 1 , 0)
		-- end
	elseif repair_item.prefab == "charcoal" then
		-- if inst.level < 40 then
			-- inst.SoundEmitter:PlaySound("dontstarve_DLC001/common/iceboulder_smash")
			-- inst.components.talker:Say("It's sharper!")
		-- elseif inst.level >= 40 then
			-- inst.components.talker:Say("It reached its limit.")
		-- end
		inst.level = math.max(inst.level - 4 , 0)
	end
	applyupgrades(inst)	
end

local function onpreload(inst, data)
	if data then
		if data.level then
			inst.level = data.level
			applyupgrades(inst)
		end 
	end
end

local function onload(inst, data)
	applyupgrades(inst)	
end

local function onsave(inst, data)
	data.level = inst.level
end

local function onfinished(inst)
    inst:Remove()
end

local function onequip(inst, owner) 
    owner.AnimState:OverrideSymbol("swap_object", "ruby_spear", "swap_spear")
	owner.SoundEmitter:PlaySound("dontstarve/wilson/equip_item_gold")
    owner.AnimState:Show("ARM_carry") 
    owner.AnimState:Hide("ARM_normal") 
end

local function onunequip(inst, owner) 
    owner.AnimState:Hide("ARM_carry") 
    owner.AnimState:Show("ARM_normal") 
end


-- (data.newpercent - data.oldpercent)*

local function fn(Sim)
	local inst = CreateEntity()
	local trans = inst.entity:AddTransform()
	local anim = inst.entity:AddAnimState()
    MakeInventoryPhysics(inst)
    
    anim:SetBank("spear")
    anim:SetBuild("rubyspear")
    anim:PlayAnimation("idle")
    
    inst:AddTag("sharp")




    
    inst:AddComponent("finiteuses")
    inst.components.finiteuses:SetMaxUses(TUNING.RUBYSPEAR_USES)
    inst.components.finiteuses:SetUses(TUNING.RUBYSPEAR_USES)
    
    inst.components.finiteuses:SetOnFinished( onfinished )

    inst:AddComponent("inspectable")
    
    inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.atlasname = "images/inventoryimages/rubyspear.xml"
    
    inst:AddComponent("equippable")
    inst.components.equippable:SetOnEquip( onequip )
    inst.components.equippable:SetOnUnequip( onunequip )
	
	inst:AddComponent("talker")
	inst.components.talker.fontsize = 30
    inst.components.talker.font = TALKINGFONT
    inst.components.talker.colour = Vector3(1, 1, 1, 1)
    inst.components.talker.offset = Vector3(200,-250,0)
	
	inst:AddComponent("repairable")
	inst.components.repairable.repairmaterial = "ASH"
	inst.components.repairable.announcecanfix = false
	inst.components.repairable.onrepaired = onrepaired
	
	inst:AddComponent("weapon")
	inst.components.weapon:SetDamage(TUNING.RUBYSPEAR_DAMAGE)
	
	inst.level = 0
	inst.OnSave = onsave
	inst.OnLoad = onload
	inst.OnPreLoad = onpreload
    applyupgrades(inst)
    return inst
end

return Prefab( "common/inventory/rubyspear", fn, assets) 
